@@ -4,7 +4,7 @@ use v5.14;
 use warnings;
 use utf8;
 
-our $VERSION = "2.26";
+our $VERSION = "2.27";
 
 use Data::Dumper;
 $Data::Dumper::Sortkeys = 1;
@@ -177,6 +177,9 @@ my @default = (
     tabhead   => ' ',
     tabspace  => ' ',
     discard   => {},
+    crackwide => 0,
+    lefthalf  => "\N{NO-BREAK SPACE}",
+    righthalf => "\N{NO-BREAK SPACE}",
     );
 
 sub new {
@@ -389,10 +392,17 @@ sub fold {
 		next;
 	    }
 	    my($a, $b, $w) = simple_fold($s, $room);
-	    if ($w > $room and $room < $width) {
+	    if ($w > $room && $room < $width) {
+		# $w == 2 && $room == 1
 		$_ = $s . $_;
 		last;
 	    }
+	    if ($opt->{crackwide} && $w == $room - 1 && $b =~ /\A(\p{IsWideSpacing})/p) {
+		# split in the middle of a full-width character
+		$a .= $opt->{lefthalf};
+		$b  = $opt->{righthalf} . ${^POSTMATCH};
+		$w++;
+	    }
 	    ($folded, $_) = ($folded . $a, $b . $_);
 	    $room -= $w;
 	} else {
@@ -578,7 +588,7 @@ Text::ANSI::Fold - Text folding library supporting ANSI terminal sequence and As
 
 =head1 VERSION
 
-Version 2.26
+Version 2.27
 
 =head1 SYNOPSIS
 
@@ -759,6 +769,10 @@ consumes all remaining strings.
     my @list = $fold->text("1223334444")->chops(width => [ 1, 0, -2, 3 ]);
     # return ("1", "", "223334444")
 
+The padding operation is performed only on the last non-empty element,
+and no elements corresponding to subsequent items are returned.  Also,
+of course, padding is not performed for negative widths.
+
 =head1 OPTIONS
 
 Option parameter can be specified as name-value list for B<ansi_fold>
@@ -868,6 +882,20 @@ Import-tag C<:constants> can be used to access these constants.
 Option B<runin> and B<runout> is used to set maximum width of moving
 characters.  Default values are both 2.
 
+=item B<crackwide> => I<bool>
+
+=item B<lefthalf> => I<char>
+
+=item B<righthalf> => I<char>
+
+It is sometimes necessary to split a string at the middle of a wide
+character.  In such cases, the string is usually split before that
+point.  If this parameter is true, that wide character is split into
+left-half and right-half character.
+
+The parameters C<lefthalf> and C<righthalf> specify the respective
+characters. Their default value is both C<NON-BREAK SPACE>.
+
 =item B<expand> => I<bool>
 
 =item B<tabstop> => I<n>
